@@ -15,7 +15,6 @@
 #include "mozilla/UniquePtr.h"
 #include "mozilla/Unused.h"
 #include "mozilla/WinTokenUtils.h"
-#include "mozilla/WindowsVersion.h"
 #include "mozilla/XREAppData.h"
 #include "mozilla/glue/WindowsDllServices.h"
 #include "mozilla/mscom/ProcessRuntime.h"
@@ -58,7 +57,7 @@ static const wchar_t kUrl[] = TELEMETRY_BASE_URL TELEMETRY_NAMESPACE
     TELEMETRY_LAUNCHER_PING_DOCTYPE TELEMETRY_LAUNCHER_PING_VERSION L"/";
 static const uint32_t kGuidCharLenWithNul = 39;
 static const uint32_t kGuidCharLenNoBracesNoNul = 36;
-static const mozilla::StaticXREAppData* gAppData;
+static const mozilla::StaticXREAppData* gStaticAppData;
 
 // Ordinarily, errors are only reported to the Windows Event Log when they are
 // not reported upstream via telemetry (usually due either to telemetry being
@@ -291,12 +290,6 @@ static const ProviderKey gProvKeys[] = {
     {WSC_SECURITY_PROVIDER_FIREWALL, "firewall"}};
 
 static bool AddWscInfo(mozilla::JSONWriter& aJson) {
-  if (!mozilla::IsWin8OrLater()) {
-    // We haven't written anything yet, so we can return true here and continue
-    // capturing data.
-    return true;
-  }
-
   // We need COM for this. Using ProcessRuntime so that process-global COM
   // configuration is done correctly
   mozilla::mscom::ProcessRuntime mscom(
@@ -312,7 +305,7 @@ static bool AddWscInfo(mozilla::JSONWriter& aJson) {
   const CLSID clsid = __uuidof(WSCProductList);
   const IID iid = __uuidof(IWSCProductList);
 
-  for (uint32_t index = 0; index < mozilla::ArrayLength(gProvKeys); ++index) {
+  for (uint32_t index = 0; index < std::size(gProvKeys); ++index) {
     // NB: A separate instance of IWSCProductList is needed for each distinct
     // security provider type; MSDN says that we cannot reuse the same object
     // and call Initialize() to pave over the previous data.
@@ -375,11 +368,11 @@ static bool AddModuleInfo(const nsAutoHandle& aSnapshot,
 
     wchar_t leaf[_MAX_FNAME] = {};
     if (::_wsplitpath_s(module.szExePath, nullptr, 0, nullptr, 0, leaf,
-                        mozilla::ArrayLength(leaf), nullptr, 0)) {
+                        std::size(leaf), nullptr, 0)) {
       return false;
     }
 
-    if (_wcslwr_s(leaf, mozilla::ArrayLength(leaf))) {
+    if (_wcslwr_s(leaf, std::size(leaf))) {
       return false;
     }
 
@@ -494,19 +487,18 @@ static bool PrepPing(const PingThreadContext& aContext, const std::wstring& aId,
   tm gmTm;
   if (!gmtime_s(&gmTm, &now)) {
     char isoTimeBuf[32] = {};
-    if (strftime(isoTimeBuf, mozilla::ArrayLength(isoTimeBuf), "%FT%T.000Z",
-                 &gmTm)) {
+    if (strftime(isoTimeBuf, std::size(isoTimeBuf), "%FT%T.000Z", &gmTm)) {
       aJson.StringProperty("creationDate", isoTimeBuf);
     }
   }
 
   aJson.StringProperty("update_channel", QUOTE_ME(MOZ_UPDATE_CHANNEL));
 
-  if (gAppData) {
+  if (gStaticAppData) {
     aJson.StringProperty("build_id",
-                         mozilla::MakeStringSpan(gAppData->buildID));
+                         mozilla::MakeStringSpan(gStaticAppData->buildID));
     aJson.StringProperty("build_version",
-                         mozilla::MakeStringSpan(gAppData->version));
+                         mozilla::MakeStringSpan(gStaticAppData->version));
   }
 
   OSVERSIONINFOEXW osv = {sizeof(osv)};
@@ -540,7 +532,7 @@ static bool PrepPing(const PingThreadContext& aContext, const std::wstring& aId,
 
   WCHAR localeName[LOCALE_NAME_MAX_LENGTH] = {};
   int localeNameLen =
-      ::GetUserDefaultLocaleName(localeName, mozilla::ArrayLength(localeName));
+      ::GetUserDefaultLocaleName(localeName, std::size(localeName));
   if (localeNameLen) {
     auto localeNameUtf8 = WideToUTF8(localeName, localeNameLen - 1);
     if (localeNameUtf8) {
@@ -654,19 +646,19 @@ static bool DoSendPing(const PingThreadContext& aContext) {
 
   wchar_t drive[_MAX_DRIVE] = {};
   wchar_t dir[_MAX_DIR] = {};
-  if (_wsplitpath_s(exePath.get(), drive, mozilla::ArrayLength(drive), dir,
-                    mozilla::ArrayLength(dir), nullptr, 0, nullptr, 0)) {
+  if (_wsplitpath_s(exePath.get(), drive, std::size(drive), dir, std::size(dir),
+                    nullptr, 0, nullptr, 0)) {
     return false;
   }
 
   wchar_t pingSenderPath[MAX_PATH + 1] = {};
-  if (_wmakepath_s(pingSenderPath, mozilla::ArrayLength(pingSenderPath), drive,
-                   dir, L"pingsender", L"exe")) {
+  if (_wmakepath_s(pingSenderPath, std::size(pingSenderPath), drive, dir,
+                   L"pingsender", L"exe")) {
     return false;
   }
 
   // Construct the telemetry URL
-  wchar_t urlBuf[mozilla::ArrayLength(kUrl) + kGuidCharLenNoBracesNoNul] = {};
+  wchar_t urlBuf[std::size(kUrl) + kGuidCharLenNoBracesNoNul] = {};
   if (wcscpy_s(urlBuf, kUrl)) {
     return false;
   }
@@ -679,8 +671,8 @@ static bool DoSendPing(const PingThreadContext& aContext) {
   wchar_t* pingSenderArgv[] = {pingSenderPath, urlBuf,
                                const_cast<wchar_t*>(fileName.c_str())};
 
-  mozilla::UniquePtr<wchar_t[]> pingSenderCmdLine(mozilla::MakeCommandLine(
-      mozilla::ArrayLength(pingSenderArgv), pingSenderArgv));
+  mozilla::UniquePtr<wchar_t[]> pingSenderCmdLine(
+      mozilla::MakeCommandLine(std::size(pingSenderArgv), pingSenderArgv));
 
   // Now start pingsender to handle the rest
   PROCESS_INFORMATION pi;
@@ -774,7 +766,7 @@ void HandleLauncherError(const LauncherError& aError,
 }
 
 void SetLauncherErrorAppData(const StaticXREAppData& aAppData) {
-  gAppData = &aAppData;
+  gStaticAppData = &aAppData;
 }
 
 void SetLauncherErrorForceEventLog() { gForceEventLog = true; }
